{% load i18n %}
{% get_current_language as LANGUAGE_CODE %}
<!DOCTYPE html>
<html lang="{{ LANGUAGE_CODE }}">
	<head>
		<meta charset="utf-8">
		<title>{% block headtitle %}{% endblock %}</title>
	</head>

	<body>
		{% block content %}{% endblock %}
	</body>
</html>
